Contact class abstract

Constructors

Contact([dynamic updates(ContactBuilder b)])
factory

Properties

addressLines → BuiltList<String>?
no setter
city → String?
no setter
countryCode → String?
no setter
email → String?
no setter
familyName → String?
no setter
givenName → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
phone → String?
no setter
postalCode → String?
no setter
region → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ContactBuilder b)) → Contact
Rebuilds the instance.
inherited
toBuilder() → ContactBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Contact>
no setter