ErrorInfo class abstract

Constructors

ErrorInfo([dynamic updates(ErrorInfoBuilder b)])
factory

Properties

code → ErrorCode
no setter
debugCode → String
no setter
debugMessage → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ErrorInfoBuilder b)) → ErrorInfo
Rebuilds the instance.
inherited
toBuilder() → ErrorInfoBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ErrorInfo>
no setter