IOSTheme class abstract

Constructors

IOSTheme([dynamic updates(IOSThemeBuilder b)?])
factory

Properties

backgroundColor → RGBAColor?
no setter
errorColor → RGBAColor?
no setter
font → Font?
no setter
foregroundColor → RGBAColor?
no setter
hashCode → int
The hash code for this object.
no setterinherited
keyboardAppearance → KeyboardAppearance?
no setter
messageColor → RGBAColor?
no setter
placeholderTextColor → RGBAColor?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveButtonFont → Font?
no setter
saveButtonTextColor → RGBAColor?
no setter
saveButtonTitle → String?
no setter
textColor → RGBAColor?
no setter
tintColor → RGBAColor?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(IOSThemeBuilder)) → IOSTheme
Rebuilds the instance.
inherited
toBuilder() → IOSThemeBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<IOSTheme>
no setter