IOSThemeBuilder class

Constructors

IOSThemeBuilder()

Properties

backgroundColor ↔ RGBAColorBuilder
getter/setter pair
errorColor ↔ RGBAColorBuilder
getter/setter pair
font ↔ FontBuilder
getter/setter pair
foregroundColor ↔ RGBAColorBuilder
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyboardAppearance ↔ KeyboardAppearance?
getter/setter pair
messageColor ↔ RGBAColorBuilder
getter/setter pair
placeholderTextColor ↔ RGBAColorBuilder
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveButtonFont ↔ FontBuilder
getter/setter pair
saveButtonTextColor ↔ RGBAColorBuilder
getter/setter pair
saveButtonTitle ↔ String?
getter/setter pair
textColor ↔ RGBAColorBuilder
getter/setter pair
tintColor ↔ RGBAColorBuilder
getter/setter pair

Methods

build() → _$IOSTheme
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(IOSTheme other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(IOSThemeBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited