RGBAColor class abstract

Constructors

RGBAColor([dynamic updates(RGBAColorBuilder b)])
factory

Properties

a → double?
no setter
b → int
no setter
g → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
r → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RGBAColorBuilder b)) → RGBAColor
Rebuilds the instance.
inherited
toBuilder() → RGBAColorBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RGBAColor>
no setter